#[non_exhaustive]pub struct PythonRepository {
pub upstream: Option<Upstream>,
/* private fields */
}Expand description
Configuration for a Python remote repository.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.upstream: Option<Upstream>Address of the remote repository.
Implementations
Sourceimpl PythonRepository
impl PythonRepository
pub fn new() -> Self
Sourcepub fn set_upstream<T: Into<Option<Upstream>>>(self, v: T) -> Self
pub fn set_upstream<T: Into<Option<Upstream>>>(self, v: T) -> Self
Sets the value of upstream.
Note that all the setters affecting upstream are mutually
exclusive.
Example
ⓘ
use google_cloud_artifactregistry_v1::model::remote_repository_config::python_repository::PublicRepository;
let x0 = PythonRepository::new().set_upstream(Some(
google_cloud_artifactregistry_v1::model::remote_repository_config::python_repository::Upstream::PublicRepository(PublicRepository::Pypi)));Sourcepub fn public_repository(&self) -> Option<&PublicRepository>
pub fn public_repository(&self) -> Option<&PublicRepository>
The value of upstream
if it holds a PublicRepository, None if the field is not set or
holds a different branch.
Sourcepub fn set_public_repository<T: Into<PublicRepository>>(self, v: T) -> Self
pub fn set_public_repository<T: Into<PublicRepository>>(self, v: T) -> Self
Sets the value of upstream
to hold a PublicRepository.
Note that all the setters affecting upstream are
mutually exclusive.
Example
ⓘ
use google_cloud_artifactregistry_v1::model::remote_repository_config::python_repository::PublicRepository;
let x0 = PythonRepository::new().set_public_repository(PublicRepository::Pypi);
assert!(x0.public_repository().is_some());
assert!(x0.custom_repository().is_none());Sourcepub fn custom_repository(&self) -> Option<&Box<CustomRepository>>
pub fn custom_repository(&self) -> Option<&Box<CustomRepository>>
The value of upstream
if it holds a CustomRepository, None if the field is not set or
holds a different branch.
Sourcepub fn set_custom_repository<T: Into<Box<CustomRepository>>>(self, v: T) -> Self
pub fn set_custom_repository<T: Into<Box<CustomRepository>>>(self, v: T) -> Self
Sets the value of upstream
to hold a CustomRepository.
Note that all the setters affecting upstream are
mutually exclusive.
Example
ⓘ
use google_cloud_artifactregistry_v1::model::remote_repository_config::python_repository::CustomRepository;
let x = PythonRepository::new().set_custom_repository(CustomRepository::default()/* use setters */);
assert!(x.custom_repository().is_some());
assert!(x.public_repository().is_none());Trait Implementations
Sourceimpl Clone for PythonRepository
impl Clone for PythonRepository
Sourcefn clone(&self) -> PythonRepository
fn clone(&self) -> PythonRepository
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PythonRepository
impl Debug for PythonRepository
Sourceimpl Default for PythonRepository
impl Default for PythonRepository
Sourcefn default() -> PythonRepository
fn default() -> PythonRepository
Returns the “default value” for a type. Read more
Sourceimpl Message for PythonRepository
impl Message for PythonRepository
Sourceimpl PartialEq for PythonRepository
impl PartialEq for PythonRepository
impl StructuralPartialEq for PythonRepository