#[non_exhaustive]pub struct ListPythonPackagesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
The request to list python packages.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The name of the parent resource whose python packages will be listed.
page_size: i32The maximum number of artifacts to return. Maximum page size is 1,000.
page_token: StringThe next_page_token value returned from a previous list request, if any.
Implementations
Sourceimpl ListPythonPackagesRequest
impl ListPythonPackagesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListPythonPackagesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListPythonPackagesRequest
impl Clone for ListPythonPackagesRequest
Sourcefn clone(&self) -> ListPythonPackagesRequest
fn clone(&self) -> ListPythonPackagesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListPythonPackagesRequest
impl Debug for ListPythonPackagesRequest
Sourceimpl Default for ListPythonPackagesRequest
impl Default for ListPythonPackagesRequest
Sourcefn default() -> ListPythonPackagesRequest
fn default() -> ListPythonPackagesRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListPythonPackagesRequest
impl Message for ListPythonPackagesRequest
impl StructuralPartialEq for ListPythonPackagesRequest