#[non_exhaustive]pub struct ListPythonPackagesResponse {
pub python_packages: Vec<PythonPackage>,
pub next_page_token: String,
/* private fields */
}Expand description
The response from listing python packages.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.python_packages: Vec<PythonPackage>The python packages returned.
next_page_token: StringThe token to retrieve the next page of artifacts, or empty if there are no more artifacts to return.
Implementations
Sourceimpl ListPythonPackagesResponse
impl ListPythonPackagesResponse
pub fn new() -> Self
Sourcepub fn set_python_packages<T, V>(self, v: T) -> Self
pub fn set_python_packages<T, V>(self, v: T) -> Self
Sets the value of python_packages.
Example
ⓘ
use google_cloud_artifactregistry_v1::model::PythonPackage;
let x = ListPythonPackagesResponse::new()
.set_python_packages([
PythonPackage::default()/* use setters */,
PythonPackage::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListPythonPackagesResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListPythonPackagesResponse
impl Clone for ListPythonPackagesResponse
Sourcefn clone(&self) -> ListPythonPackagesResponse
fn clone(&self) -> ListPythonPackagesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListPythonPackagesResponse
impl Debug for ListPythonPackagesResponse
Sourceimpl Default for ListPythonPackagesResponse
impl Default for ListPythonPackagesResponse
Sourcefn default() -> ListPythonPackagesResponse
fn default() -> ListPythonPackagesResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListPythonPackagesResponse
impl Message for ListPythonPackagesResponse
impl StructuralPartialEq for ListPythonPackagesResponse